SystemOrganization addCategory: #'CS528-Project'!
SystemOrganization addCategory: #'CS528-Project-Seaside'!
SystemOrganization addCategory: #'CS528-Project-Websocket'!

ZnWebSocket subclass: #TableWebsocket
	instanceVariableNames: 'tableID delegate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!TableWebsocket commentStamp: '<historical>' prior: 0!
A TableWebsocket is an abstraction over the websocket connection between a PokerPlayer and the PokerTable they are currently a member of. It is a reference maintained by the PokerPlayer so that 

Instance Variables
	delegate:		<PokerPlayer>
	tableID:		<string>

delegate
	- PokerPlayer which will be required to handle incoming messages on this websocket. Must implement onMessage: message.

tableID
	- string representing the ID of the table this websocket is connected to.
!

!TableWebsocket class methodsFor: 'initialize' stamp: 'BrianDentino 7/11/2013 21:45'!
tableID: id delegate: aDelegate 
	^ ((TableWebsocket to: 'ws://localhost:', ZnServer default port asString, '/', id) tableID: id) delegate: aDelegate.! !

!TableWebsocket methodsFor: 'initialize-release' stamp: 'lb 6/13/2013 21:46'!
delegate: aDelegate
	delegate := aDelegate.
	[[self runWith: [ :message |
      	self crLog: 'PokerPlayer received message from table: ', message printString. 
		delegate onMessage: message from: self].] on: ConnectionClosed do: [ self log debug: '==Connection Closed'] ] fork.! !

!TableWebsocket methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/11/2013 23:08'!
initialize
	super initialize.
	self role: #server.! !

!TableWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/6/2013 22:24'!
tableID: id
	tableID := id! !

WAComponent subclass: #ActionButton
	instanceVariableNames: 'callback text'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!ActionButton class methodsFor: 'initialize-release' stamp: 'BrianDentino 7/18/2013 03:43'!
with: aString onClick: aCallback 
	^ self new text: aString; onClick: aCallback.! !

!ActionButton methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 03:41'!
onClick: aCallback
	callback := aCallback.! !

!ActionButton methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 03:42'!
renderContentOn: html
	html submitButton 
		onClick: ( html jQuery ajax
			callback: [ callback value ] );
		with: text.! !

!ActionButton methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 03:51'!
text: aString 
	text := aString.! !

WAComponent subclass: #BetButton
	instanceVariableNames: 'betCallback'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!BetButton commentStamp: '<historical>' prior: 0!
A BetButton is a simple button that evaluates 'betCallback' when clicked.

Instance Variables
	betCallback:		<Block> 

betCallback
	- Callback to be evaluated when button is clicked. Should not expect any arguments.
!

!BetButton class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/14/2013 20:31'!
onBet: aCallback
	^(self new onBet: aCallback).! !

!BetButton methodsFor: 'rendering' stamp: 'BrianDentino 7/14/2013 20:31'!
onBet: aCallback
	betCallback := aCallback.! !

!BetButton methodsFor: 'rendering' stamp: 'BrianDentino 7/15/2013 23:00'!
renderContentOn: html
	html submitButton 
		onClick: ( html jQuery ajax
			callback: [ betCallback value ] );
		with: 'Bet'.! !

WAComponent subclass: #BetSlider
	instanceVariableNames: 'min max step betAmount'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!BetSlider commentStamp: '<historical>' prior: 0!
A BetSlider is a renderable component that presents a slider and label indicating the current value of the slider.

Instance Variables
	betAmount:		<Number> current bet
	max:		<Number> max slider value
	min:		<Number> min slider value
	step:		<Number> slider increment interval

betAmount
	- xxxxx

max
	- xxxxx

min
	- xxxxx

step
	- xxxxx
!

!BetSlider class methodsFor: 'initialize' stamp: 'BrianDentino 7/15/2013 23:08'!
min: minValue max: maxValue step: stepValue
	^ (self new) min: minValue; max: maxValue; step: stepValue.! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/15/2013 22:34'!
betAmount
	^betAmount.! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 04:13'!
betAmount: anAmount
	betAmount := anAmount.! !

!BetSlider methodsFor: 'initialize' stamp: 'BrianDentino 7/15/2013 23:12'!
initialize
	super initialize. 
	min := 0.
	max := 0.
	step := 0.
	betAmount := 0.! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/15/2013 23:09'!
max: aValue
	max := aValue! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 02:54'!
min: aValue
	min := aValue.
	betAmount := min! !

!BetSlider methodsFor: 'rendering' stamp: 'BrianDentino 7/16/2013 04:17'!
renderContentOn: html
	| labelID sliderID |
	
	labelID := html nextId.
	sliderID := html nextId.
	
	html div 
		id: sliderID;
		script: (html jQuery new slider
			min: min;
			max: max;
			step: step;
			value: betAmount;
			orientation: #vertical;
			onSlide: [ :value | ( html jQuery script: [ :s | s << (s jQuery id: labelID) text: value ] ) ]
			
			"; 
			Not actually using this anymore, but leaving it in as documentation for how to setup ajax callbacks.
			
			onChange: [ :value | ( html jQuery ajax 
				callback: [ :amount | self betAmount: amount asNumber ] value: (value) ) ] ).
			"
			
			).
		
	html space.
	html space.
	html div id: labelID;
		with: betAmount! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/15/2013 23:09'!
step: aValue
	step := aValue! !

WAComponent subclass: #CardComponent
	instanceVariableNames: 'suit rank'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!CardComponent commentStamp: '<historical>' prior: 0!
A CardComponent is a Seaside Component that represents a playing card.

Instance Variables
	rank:		<String>
	suit:		<String>

rank
	- Rank of the card (i.e. 'Ace', '4', 'King', etc)

suit
	- Suit of the card ('Hearts', 'Spades', 'Clubs', 'Diamonds')
!

!CardComponent class methodsFor: 'initialization' stamp: 'BrianDentino 7/18/2013 00:52'!
suit: aSuit rank: aRank 
	^(self new suit: aSuit; rank: aRank).! !

!CardComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:49'!
rank
	^rank.! !

!CardComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:49'!
rank: aRank
	rank := aRank.! !

!CardComponent methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 00:51'!
renderContentOn: html 
	html div
		class: 'card';
		with: [ 
			html div 
				class: 'suit';	
				with: suit.
				
			html div 
				class: 'rank';
				with: rank.
		 ].! !

!CardComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:49'!
suit
	^suit.! !

!CardComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:49'!
suit: aSuit 	
	suit := aSuit.! !

WAComponent subclass: #CardSetComponent
	instanceVariableNames: 'cards'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!CardSetComponent commentStamp: '<historical>' prior: 0!
A CardSetComponent is a Seaside Component representing a set of cards (a 'hand', if you will).

Instance Variables
	cards:		<OrderedCollection>

cards
	- set of CardComponents
!

!CardSetComponent methodsFor: 'adding' stamp: 'BrianDentino 7/18/2013 00:54'!
addCard: aCard 
	cards add: aCard.! !

!CardSetComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:53'!
cards
	^ cards.! !

!CardSetComponent methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 00:57'!
initialize
	super initialize.
	cards := OrderedCollection new.! !

!CardSetComponent methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 01:00'!
renderContentOn: html 
	html div 
		class: 'cardSet';
		with: [ 
			cards do: [ :card | html render: card ].
		].! !

WAComponent subclass: #DrawButton
	instanceVariableNames: 'drawCallback'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!DrawButton class methodsFor: 'as yet unclassified' stamp: 'lb 6/13/2013 22:12'!
onDraw: aCallback
	^(self new onDraw: aCallback).! !

!DrawButton methodsFor: 'as yet unclassified' stamp: 'lb 6/13/2013 22:31'!
onDraw: aCallback
	drawCallback := aCallback.! !

!DrawButton methodsFor: 'as yet unclassified' stamp: 'lb 6/13/2013 22:11'!
renderContentOn: html
	html submitButton 
		onClick: ( html jQuery ajax
			callback: [drawCallback value ] );
		with: 'Draw'.! !

WAComponent subclass: #PokerPlayerComponent
	instanceVariableNames: 'name money lastAction active'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!PokerPlayerComponent commentStamp: '<historical>' prior: 0!
A PlayerWidget is a simple WAComponent for rendering a player .

Instance Variables
	money:		<Number>
	name:		<String>

money
	- amount of money the player has.

name
	- user id
!

!PokerPlayerComponent class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 03:06'!
name: aName money: anAmount
	^(self new name: aName; money: anAmount; lastAction: 'None'; active: false).! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:35'!
active
	^active.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:35'!
active: isActive
	active := isActive.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:35'!
lastAction
	^lastAction.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 00:35'!
lastAction: anActionMessage 
	lastAction := anActionMessage.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 22:15'!
money
	^money.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 22:15'!
money: anAmount
	money := anAmount.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 22:15'!
name 
	^name.! !

!PokerPlayerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 22:14'!
name: aName
	name := aName.! !

!PokerPlayerComponent methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 02:02'!
renderContentOn: html

 	html div 
		class: 'pokerPlayer';
		with: [ 
			html div 
				class: ( active ifTrue: ['activePlayer'] ifFalse: [''] );
				class: 'playerWidget'; 
				with: [  
					html div 
						class: 'playerName';
						with: name.
		
					html div 
						class: 'playerMoney';
						with: '$', (money asString).
				].
	
			html div 
				class: 'playerAction';
				with: lastAction.
		].! !

!PokerPlayerComponent methodsFor: 'hooks' stamp: 'BrianDentino 7/16/2013 21:55'!
style
	^'
	.playerWidget {
    		border: 2px solid #064c0e;   
    		border-radius: 10px;
    		-webkit-border-radius: 10px;
    		-moz-border-radius: 10px;
    
    		width: 120px;
    		padding: 5px 10px;
    
    		background-image: -webkit-gradient(linear, 0 100%, 0 0, color-stop(0.18, rgb(52,82,60)), color-stop(0.74, rgb(104,158,122)));
    		background-image: -webkit-linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
    		background-image: -moz-linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
    		background-image: -o-linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
    		background-image: linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
	}

	.playerName {
    		color : white;
    		font-family: monospace;
    		font-size: 14px;
    		padding: 5px 0px 5px;
    		position: relative;
    		width: 100%;
    		text-align: center;
	}

	.playerMoney {
    		color : #FFE4B5;
    		font-family: monospace;
    		font-size: 18px;
    		padding: 0px 0px 5px;
    		position: relative;
    		width: 96%;
    		text-align: center;
	}'! !

WAComponent subclass: #PokerPlayerView
	instanceVariableNames: 'playerID tableID table browser tableComponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

PokerPlayerView class
	instanceVariableNames: 'nextID'!

!PokerPlayerView commentStamp: '<historical>' prior: 0!
A PokerPlayer is a Seaside component that manages client decisions. When the state of a game changes, the PokerPlayer class notifies the view via a websocket connection to the browser.

Instance Variables
!

PokerPlayerView class
	instanceVariableNames: 'nextID'!

!PokerPlayerView class methodsFor: 'initialize' stamp: 'BrianDentino 7/12/2013 02:13'!
initialize 
	super initialize.
	nextID := 0.! !

!PokerPlayerView class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/12/2013 02:17'!
nextID
	nextID := nextID + 1.
	^ nextID asString.! !

!PokerPlayerView class methodsFor: 'initialize' stamp: 'lb 6/13/2013 19:18'!
tableID: table
	^(self new tableID: table playerID: PokerPlayerView nextID)! !

!PokerPlayerView methodsFor: 'websockets' stamp: 'BrianDentino 7/12/2013 01:47'!
close
	table close.! !

!PokerPlayerView methodsFor: 'websockets' stamp: 'lb 7/18/2013 01:42'!
comm

	table sendMessage: (WebsocketMessage id: 'comm' content: '') json.! !

!PokerPlayerView methodsFor: 'actions' stamp: 'lb 7/18/2013 01:42'!
draw

	table sendMessage: (WebsocketMessage id: 'draw' content: '') json.! !

!PokerPlayerView methodsFor: 'initialize-release' stamp: 'BrianDentino 7/18/2013 01:41'!
initialize 
	super initialize.
	browser := BrowserWebsocket delegate: self.
	tableComponent := PokerTableComponent new.! !

!PokerPlayerView methodsFor: 'websockets' stamp: 'lb 7/18/2013 00:49'!
onMessage: aMessage from: websocket
	(websocket == table) ifTrue: [ browser sendMessage: aMessage ].
	(websocket == browser) ifTrue: [ table sendMessage: aMessage ].! !

!PokerPlayerView methodsFor: 'actions' stamp: 'BrianDentino 7/18/2013 03:19'!
placeBet: anAmount 

	| action |
	
	action := Dictionary new.
	action at: 'actionType' put: 'bet'.
	action at: 'amount' put: anAmount.
	
	self sendPlayerAction: action! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'lb 7/13/2013 15:16'!
playerID
	^ playerID! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 03:45'!
renderContentOn: html
	"| betSlider |"

"	betSlider := BetSlider min: 5 max: 100 step: 5."

	html text: 'Welcome to table ', tableID, '. You are player ', playerID, '.'.
	html horizontalRule.
	
	html render: (ActionButton with: 'Activate' onClick: [ self requestActivation ]).
	html horizontalRule.
"	
	html render: betSlider.
	html horizontalRule.
	
	html render: (PokerPlayerComponent name: 'brian' money: 500)."
	html div id: 'pokerTable';
		with: [ 
			html render: tableComponent.
		].
	
	html render: (WebsocketHandlerComponent wsAddress: 'ws://localhost:1701/', tableID, '_', playerID).
	
	 self renderJSPlayersUpdateOn: html.! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 03:13'!
renderJSPlayersUpdateOn: html
	html script: 
	'
	updatePlayers = function() { 
		var elems = document.getElementsByClassName("pokerPlayer");
		var increase = Math.PI * 2 / elems.length;
		var x = 0, y = 0, angle = 0, elem;

		for (var i = 0; i < elems.length; i++) {
    			elem = elems[i];
    			x = 200 * Math.cos(angle) + 400;
    			y = 200 * Math.sin(angle) + 400;
    			elem.style.position = "absolute";
    			elem.style.left = x + "px";
    			elem.style.top = y + "px";
    			angle += increase;
		}
	}
	'.! !

!PokerPlayerView methodsFor: 'actions' stamp: 'BrianDentino 7/18/2013 03:46'!
requestActivation

	table sendMessage: (WebsocketMessage id: 'activate' content: playerID) json.! !

!PokerPlayerView methodsFor: 'websockets' stamp: 'lb 7/18/2013 01:24'!
sendPlayerAction: anAction

	table sendMessage: (WebsocketMessage id: 'playerAction' content: anAction) json.! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 03:55'!
style
	^ '
	div { 
		font-family: monospace;
		text-align: center;
	}
	
	.playerWidget {
    		border: 2px solid #064c0e;   
    		border-radius: 10px;
    		-webkit-border-radius: 10px;
    		-moz-border-radius: 10px;
    
    		width: 120px;
    		padding: 5px 10px;
    
    		background-image: -webkit-gradient(linear, 0 100%, 0 0, color-stop(0.18, rgb(52,82,60)), color-stop(0.74, rgb(104,158,122)));
    		background-image: -webkit-linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
    		background-image: -moz-linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
    		background-image: -o-linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
    		background-image: linear-gradient(bottom, rgb(52,82,60) 18%, rgb(104,158,122) 74%);
	}
	
	.activePlayer {
    		border: 2px solid #400000;
    		background-image: linear-gradient(bottom, rgb(82, 52, 72) 18%, rgb(156, 103, 135) 74%);
    		background-image: -o-linear-gradient(bottom, rgb(82, 52, 72) 18%, rgb(156, 103, 135) 74%);
    		background-image: -moz-linear-gradient(bottom, rgb(82, 52, 72) 18%, rgb(156, 103, 135) 74%);
    		background-image: -webkit-linear-gradient(bottom, rgb(82, 52, 72) 18%, rgb(156, 103, 135) 74%);
    		background-image: -ms-linear-gradient(bottom, rgb(82, 52, 72) 18%, rgb(156, 103, 135) 74%);
    		background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0.18, rgb(82, 52, 72)), color-stop(0.74, rgb(156, 103, 135)));
	}

	.playerName {
    		color : white;
    		font-family: monospace;
    		font-size: 14px;
    		padding: 5px 0px 5px;
    		position: relative;
    		width: 100%;
    		text-align: center;
	}

	.playerMoney {
    		color : #FFE4B5;
    		font-family: monospace;
    		font-size: 18px;
    		padding: 0px 0px 5px;
    		position: relative;
    		width: 96%;
    		text-align: center;
	}'.! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 21:29'!
tableID
	^tableID! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 01:38'!
tableID:  aTableID playerID: aPlayerID
	| url |
	tableID := aTableID.
	playerID := aPlayerID.
	url := tableID, '_', playerID.
	table := TableWebsocket tableID: tableID delegate: self.
	
	ZnServer default delegate map: url to: (ZnWebSocketDelegate map: url to: browser).! !

WAComponent subclass: #PokerTableComponent
	instanceVariableNames: 'players cards pot'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!PokerTableComponent commentStamp: '<historical>' prior: 0!
A PokerTableComponent is a Seaside Component representing a poker table.

Instance Variables
	cards:		<CardSetComponent>
	players:		<Dictionary>
	pot:		<Number>

cards
	- Set of cards on the table

players
	- Dictionary of PokerPlayerComponents, indexed by player name

pot
	- amount of money in the pot
!

!PokerTableComponent methodsFor: 'gameOperations' stamp: 'BrianDentino 7/18/2013 02:59'!
addPlayer: aPlayer
	players at: (aPlayer name) put: aPlayer.! !

!PokerTableComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 01:18'!
cards
	^cards.! !

!PokerTableComponent methodsFor: 'gameOperations' stamp: 'BrianDentino 7/18/2013 01:18'!
incrementPot: anAmount
	pot := pot + anAmount.! !

!PokerTableComponent methodsFor: 'initialization' stamp: 'BrianDentino 7/18/2013 03:17'!
initialize
	super initialize.
	cards := CardSetComponent new.
	pot := 0.
	players := Dictionary new.! !

!PokerTableComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 01:36'!
players
	^players.! !

!PokerTableComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 01:18'!
pot
	^pot.! !

!PokerTableComponent methodsFor: 'gameOperations' stamp: 'BrianDentino 7/18/2013 01:16'!
removePlayer: aPlayer
	players removeAt: (aPlayer name).! !

!PokerTableComponent methodsFor: 'rendering' stamp: 'BrianDentino 7/18/2013 01:59'!
renderContentOn: html
	html div class: 'pokerTable';
		with: [ 
			html div id: 'pokerPlayers';
				with: [  
					players do: [ :p | html render: p ]
				].
			
			html div id: 'communityCards';
				with: [ 
					html render: cards.
				].
			
			html div class: 'pot';
				with: 'Pot: ', pot.
		 ].! !

WAComponent subclass: #ProjectLanding
	instanceVariableNames: ''
	classVariableNames: 'tables'
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

ProjectLanding class
	instanceVariableNames: 'tables'!

!ProjectLanding commentStamp: '<historical>' prior: 0!
A ProjectLanding is a Seaside component that renders a page which allows users to create or join tables for hosting/playing poker games.

Instance Variables
	tables:		<Object>

tables
	- a dictionary of all active tables. key (tableID) maps to PokerTable object.
!

ProjectLanding class
	instanceVariableNames: 'tables'!

!ProjectLanding class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/5/2013 22:42'!
canBeRoot
	^ true! !

!ProjectLanding class methodsFor: 'testing' stamp: 'BrianDentino 7/16/2013 02:49'!
initialize 
	"ProjectLanding initialize"
	
	(WAAdmin register: self asApplicationAt: 'landing')
		addLibrary: JQDeploymentLibrary;
		addLibrary: JQUiDeploymentLibrary;
		addLibrary: JQCupertinoTheme.
	tables := Dictionary new.! !

!ProjectLanding class methodsFor: 'testing' stamp: 'BrianDentino 7/12/2013 01:00'!
tables
	^tables.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/12/2013 01:00'!
createNewTable
	| id |
	id := self request: 'Enter a Table ID:'.
	(ProjectLanding tables) at: id put: (PokerTable id: id).
	self joinTable: id.! !

!ProjectLanding methodsFor: 'initialization' stamp: 'BrianDentino 7/12/2013 00:57'!
initialize 
	super initialize.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/12/2013 01:06'!
joinExistingTable
	| id |
	id := self requestTableID.
	self joinTable: id.
	! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/15/2013 23:20'!
joinTable: tableID
	self call: (PokerPlayerView tableID: tableID).
	! !

!ProjectLanding methodsFor: 'rendering' stamp: 'BrianDentino 7/14/2013 14:49'!
renderContentOn: html
	html heading: 'Welcome to Smalltalk Casino!!'.
	html anchor
		callback: [ self createNewTable. ];
		with: 'Start a table'.
	html space.
	html anchor
		callback: [ self joinExistingTable. ];
		with: 'Join a table'.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/6/2013 02:09'!
requestTableID
	| id |
	id := self request: 'Enter a Table ID:'.
	^id! !

!ProjectLanding methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/5/2013 22:46'!
states
	^ Array with: self.! !

WAComponent subclass: #WebsocketHandlerComponent
	instanceVariableNames: 'wsAddress id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Seaside'!

!WebsocketHandlerComponent commentStamp: '<historical>' prior: 0!
A WebsocketHandlerComponent is a simple Seaside component that renders javascript capable of establishing a websocket connection between the rendering browser and a websocket server at the address held in wsAddress.

Along with connection logic, it renders a simple message handler that the browser will run. This handler expects JSON encoded messages with an 'id' property and a 'content' property. The message handler will replace the content of the DOM element identified by 'id' with the text of the 'content' property.

Instance Variables
	wsAddress:		<string>

wsAddress
	- string representation of the websocket address
	i.e. 'ws://10.0.0.3:8888/client'
!

!WebsocketHandlerComponent class methodsFor: 'initialize' stamp: 'BrianDentino 7/11/2013 19:51'!
wsAddress: address
	^ (self new) wsAddress: address.! !

!WebsocketHandlerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 20:00'!
id
	^id! !

!WebsocketHandlerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 20:00'!
initialize
	super initialize.
	id := 'websocket'! !

!WebsocketHandlerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/17/2013 23:53'!
renderContentOn: html

	html script: '	
	var conn = {};
	conn = new WebSocket("', wsAddress, '");
 
	conn.onmessage = function (event) {
		console.log(event.data);
		var json = event.data;
		var obj = JSON.parse(json); /** TODOhow to get jquery to work?? */
		
		console.log(obj.id);
		console.log(obj.content);
		
		var elt = document.getElementById(obj.id);
		elt.innerHTML = obj.content;
		updatePlayers();

    	};
    
    	conn.onclose = function (event) {
		console.log("connection closed")
    	};
	
'! !

!WebsocketHandlerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/11/2013 19:52'!
wsAddress
	^wsAddress! !

!WebsocketHandlerComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/11/2013 19:52'!
wsAddress: address
	wsAddress := address.! !

Object subclass: #BrowserWebsocket
	instanceVariableNames: 'delegate websocket lock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!BrowserWebsocket commentStamp: '<historical>' prior: 0!
A BrowserWebsocket is an abstraction over the websocket connection between a client PokerPlayer and the browser rendering it.

Instance Variables
	delegate:		<Object>

delegate
	- xxxxx
!

!BrowserWebsocket class methodsFor: 'initialize' stamp: 'BrianDentino 7/11/2013 22:20'!
delegate: aDelegate 
	^(self new delegate: aDelegate).! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/11/2013 22:20'!
delegate: aDelegate
	delegate := aDelegate.! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/12/2013 00:05'!
initialize
	lock := Mutex new.! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'lb 7/12/2013 16:25'!
sendMessage: aMessage
	websocket isNil ifTrue: [ Transcript show: 'browser websocket not ready yet...' ]
		ifFalse: [ websocket sendMessage: aMessage ].! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'lb 7/18/2013 01:42'!
value: aWebsocket 
	websocket := aWebsocket.
	
	lock critical: [ delegate 
		onMessage: ((WebsocketMessage id: 'joining' content:  (delegate playerID)) json) 
		from: self. ].
		
	[ websocket runWith: [ :message |
		websocket log info: [
			 'PokerPlayer received message from browser: ', message printString. 
		].
		lock critical: [ delegate onMessage: message from: self. ].
	]. ]
	on: ConnectionClosed 
	do: [ 
		websocket log debug: '**Connection close, cleaning up'.
		delegate close.
	].! !

!BrowserWebsocket methodsFor: 'as yet unclassified' stamp: 'lb 7/12/2013 13:42'!
websocket
^ websocket! !

Object subclass: #PokerTable
	instanceVariableNames: 'id lock tableModel players'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!PokerTable commentStamp: '<historical>' prior: 0!
A PokerTable is a container for clients playing poker together. Each client is represented by a websocket. When the game state is updated, the table broadcasts updates to each of the clients.

Instance Variables
!

!PokerTable class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 20:06'!
id: anIdentifier 
	^ PokerTable new id: anIdentifier.! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 03:47'!
activatePlayer: playerID
	tableModel players do: [ :player | player active: (player name = playerID) ].
	
	self broadcastTableUpdate.
	! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 02:19'!
addCommunityCard: aCard

	tableModel cards add: aCard.
	self broadcastTableUpdate.
	
	"self broadcast: (WebsocketMessage id: 'theBoard' content: aCard shortForm) json"! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 02:18'!
addPlayer: aPlayerID at: aWebsocket

	players at: aPlayerID put: aWebsocket.
	tableModel addPlayer: (PokerPlayerComponent name: aPlayerID money: 500).
	
	self broadcastTableUpdate.
	! !

!PokerTable methodsFor: 'websocket' stamp: 'lb 6/13/2013 21:48'!
broadcast: aMessage
	"Send message to all connected clients"
	lock critical: [ 
		players keysAndValuesDo: [  :playerID :ws |
			[ ws sendMessage: aMessage ]
				on: NetworkError
				do: [  :exception | 
					ws log debug: [ exception printString, ' NetworkError in broadcast...ignoring' ] ] ] ]! !

!PokerTable methodsFor: 'websocket' stamp: 'BrianDentino 7/18/2013 03:08'!
broadcastTableUpdate
	| content msg |

	content := WARenderCanvas builder render: tableModel.	
	msg := (WebsocketMessage id: 'pokerTable' content: content) json.
	self broadcast: msg.! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 21:50'!
clear
	players keysDo: [ :playerID | players removeKey: playerID.  ] ! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/18/2013 01:10'!
dealCard: aCard to: aPlayerID

	(players at: aPlayerID) sendMessage: (WebsocketMessage id: 'cards' content: aCard shortForm) json.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/17/2013 21:58'!
gameFlowMessage: aString
	self halt.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/17/2013 21:58'!
getPlayerAction: aPlayerID
	self halt.! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 18:50'!
id
	^id! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/11/2013 23:27'!
id: anIdentifier 
	id := anIdentifier.
	ZnServer default delegate map: id to: (ZnWebSocketDelegate map: id to: self).! !

!PokerTable methodsFor: 'initialize-release' stamp: 'BrianDentino 7/18/2013 02:06'!
initialize 
	players := Dictionary new.
	tableModel := PokerTableComponent new.
	lock := Mutex new.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 6/13/2013 21:48'!
players
	^ players! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 21:49'!
register: clientWebSocket
	Transcript show: 'shouldn''t be calling register...'
"	lock critical: [ 
		players at: id add: clientWebSocket ]."! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 21:48'!
unregister: clientWebSocket
	lock critical: [ 
		players keysAndValuesDo: [ :playerID :ws | ws = clientWebSocket ifTrue: [ players removeKey: playerID.  ] ]  ] .
	(players size = 0) ifTrue: [ProjectLanding tables removeKey: id]! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/18/2013 00:56'!
updatePlayerAction: aPlayerAction
	
	self broadcast: (WebsocketMessage id: 'updatePlayerAction' content: aPlayerAction) json.! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 19:23'!
value: websocket

	| msg handler |

	[ "self register: websocket."
		websocket runWith: [ :message |
			
			websocket log info: [ 'PokerTable received message: ', message printString ].

			msg := WebsocketMessage json: message.

			Transcript show: '*******'; show: msg id; show: msg content.
			
			handler := WebsocketMessageHandlerFactory getHandlerFor: msg. 
			
			handler handleMessage: msg from: websocket to: self.
			
		].
			
	]
	on: ConnectionClosed 
	do: [ 
		websocket log debug: '!!!!Connection close, cleaning up'.
		self unregister: websocket ].! !

Object subclass: #WebsocketMessage
	instanceVariableNames: 'id content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!WebsocketMessage commentStamp: '<historical>' prior: 0!
A WebsocketMessage is an object intended to represent a websocket message. It contains an id, so the receiver can identify the type of message, as well as content.

Instance Variables
	content:		<string>
	id:		<string>

content
	- String intended to be interpreted as the content of the message

id
	- String intented to be interpreted as the message identifier.
!

!WebsocketMessage class methodsFor: 'creation' stamp: 'lb 7/13/2013 14:05'!
id: aStringId content: aStringContent 
	^ (self new id: aStringId) content: aStringContent.! !

!WebsocketMessage class methodsFor: 'as yet unclassified' stamp: 'lb 7/13/2013 15:08'!
json: aJsonString

	 |obj |
	
	obj := Json readFrom: (ReadStream on: aJsonString).

	^ WebsocketMessage id: obj id content: obj content! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 19:56'!
content
	^content.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'BrianDentino 7/18/2013 03:23'!
content: aString 
	content := aString.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 19:56'!
id
	^id.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'lb 7/13/2013 14:05'!
id: aString 
	id := aString.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'lb 7/13/2013 15:05'!
json

	^ Json render: self! !

!WebsocketMessage methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 00:47'!
jsonWriteOn: aWriteStream
	
	aWriteStream nextPutAll: '{ "id" : '.
	aWriteStream nextPutAll: (Json render: id).
	aWriteStream nextPutAll: ', "content" : '.
	"content isDictionary ifTrue: [ aWriteStream nextPutAll: '{' ]."
	aWriteStream nextPutAll: (Json render: content).
	"content isDictionary ifTrue: [ aWriteStream nextPutAll: '}' ]."
	aWriteStream nextPutAll: ' }'.
	^ aWriteStream contents! !

Object subclass: #WebsocketMessageHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

WebsocketMessageHandler subclass: #ActivateMessageHandlerTESTING
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!ActivateMessageHandlerTESTING methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 03:47'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	" just for testing...this message simulates a user action that makes the requesting player active "
	aTable activatePlayer: aWebsocketMessage content.! !

WebsocketMessageHandler subclass: #CommMessageHandlerTESTING
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!CommMessageHandlerTESTING methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:25'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	" just for testing... the addCommunityCard function should be called by the game not ever the browser message handlers "
	aTable addCommunityCard: (Card newWithSuit: Suit diamonds value: CardValue five)! !

WebsocketMessageHandler subclass: #DrawMessageHandlerTESTING
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!DrawMessageHandlerTESTING methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:26'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	" just for testing... the dealCard function should be called by the game not ever the browser message handlers "
	
	| id |
	aTable players keysAndValuesDo: [ :playerID :ws | ws = aWebsocket ifTrue: [ id := playerID] ].
	
	aTable dealCard: (Card newWithSuit: Suit clubs value: CardValue queen) to: id.! !

WebsocketMessageHandler subclass: #JoinMessageHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!JoinMessageHandler methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:42'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	
	"adds a player to the dictionary of players... even if a websocket connects the player doesn't officially
	join the game until a Joining message is sent (because we need the playerID)"
	
	"add the player to the game... then somewhere we need to add them to the websocket list as well ** so need websocket here ** "
	aTable addPlayer: aWebsocketMessage content at: aWebsocket.! !

WebsocketMessageHandler subclass: #PlayerActionMessageHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!PlayerActionMessageHandler methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:23'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable "shouldn't need these other 2 args i don't think(?)... just for now"
	
	| jsonObj action |

	jsonObj := aWebsocketMessage content.
	
	action := THPlayerActionFactory new create: jsonObj.
	
	" do something with the action... "
	
	aTable updatePlayerAction: action. " then this line would be after whatever you do with the action... "! !

!WebsocketMessageHandler methodsFor: 'as yet unclassified' stamp: 'lb 7/16/2013 12:57'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	self subclassResponsibility! !

Object subclass: #WebsocketMessageHandlerFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project-Websocket'!

!WebsocketMessageHandlerFactory class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/18/2013 03:39'!
getHandlerFor: msg
				
	(msg id = 'playerAction')
		ifTrue: [ ^ PlayerActionMessageHandler new ].	
			
	(msg id = 'joining') 
		ifTrue: [ ^ JoinMessageHandler new. ].	
					
	(msg id = 'draw') 
		ifTrue: [ ^ DrawMessageHandlerTESTING new. ].
	
	(msg id = 'comm')
		ifTrue: [  ^ CommMessageHandlerTESTING new ].		
				
	(msg id = 'activate')
		ifTrue: [ ^ ActivateMessageHandlerTESTING new ].
		
	"Should never reach this point"
	self error: 'Unknown Message ID: ' , msg id.! !
ProjectLanding initialize!
PokerPlayerView initialize!
